﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using ProxyLayer;
using System.IO;

namespace BPMTestApplication
{
    [System.Runtime.InteropServices.ComVisibleAttribute(true)]
    public partial class ViewWorkItem : Form
    {

        private DataTable dataTable1 = new DataTable("Work Item View");

        private workResponse _item;

        private Adapter _adapter;

        private string _guid;

        private bool _formClosed = false;
        private WorkItem _workItem;

        public ViewWorkItem(Adapter adapter, string guid, WorkItem workItem) 
        {
            InitializeComponent();
            webBrowser1.AllowWebBrowserDrop = false;
            //webBrowser1.IsWebBrowserContextMenuEnabled = false;
            webBrowser1.WebBrowserShortcutsEnabled = false;
            webBrowser1.ObjectForScripting = this;
            this.StartPosition = FormStartPosition.CenterParent;
            _adapter = adapter;
            _guid = guid;
            _workItem = workItem;
            try
            {
                _item = _adapter.OpenItem(_guid, workItem);
                ShowItem();
            }
            catch (Exception ex)
            {
                MessageBox.Show("ERROR: Failed to open item: " + ex.Message);
                throw ex;
            }
        }

        
        public void ShowItem() 
        {
            Text = "Viewing item: " + _item.presentation.activityName;
            HtmlDocument doc = webBrowser1.Document;
            string pathToHTML = Environment.CurrentDirectory + "/FormRedirect.htm";

            StreamReader streamReader = new StreamReader(pathToHTML);
            string htmlText = streamReader.ReadToEnd();
            streamReader.Close();
            htmlText = htmlText.Replace("%%SCRIPT_LOCATION%%", _adapter.GetJSURL());

            // Now create a temporary file for the HTML page with the correct host location

            string tempFile = Path.GetTempFileName();
            FileStream File_Stream = new FileStream(tempFile, FileMode.Create, FileAccess.Write);
            StreamWriter FileWriter = new StreamWriter(File_Stream);
            try
            {
                FileWriter.BaseStream.Seek(0, SeekOrigin.End);
                FileWriter.Write(htmlText);
            }
            finally
            {
                FileWriter.Close();
            }
            webBrowser1.Url = new Uri(tempFile);


        }

        public string GetFormURL()
        {
            return _adapter.GetFormURL(_item);
        }

        public string GetInitData()
        {
            return (String)_item.payloadModel.Item;

        }



        public string GetBOMJSPath()
        {
            return _adapter.GetBOMJSPath(_item);
        }

        public string getJSURL()
        {
            return _adapter.GetJSURL();
        }

        public void SubmitForm(string data)
        {
            try
            {
                _adapter.SubmitWorkItem(_workItem, _item.workTypeDetail.uid, _item.workTypeDetail.version, _guid, data);
                _formClosed = true;
                Close();
            }
            catch (Exception e)
            {
                MessageBox.Show("Error closing form: " + e.Message);
            }
        }


        public void CloseForm(string data)
        {
            try
            {
                _adapter.CloseWorkItem(_workItem, _item.workTypeDetail.uid,_item.workTypeDetail.version,_guid, data);
                _formClosed = true;
                Close();
            }
            catch (Exception e)
            {
                MessageBox.Show("Error closing form: " + e.Message);
            }
        }

        public void WindowClosed(object sender, FormClosedEventArgs e)
        {
            if (!_formClosed)
            {
                CancelForm();
            }
        }

        public void CancelForm()
        {
            try
            {
                _adapter.CancelWorkItem(_workItem, _item.workTypeDetail.uid, _item.workTypeDetail.version, _guid);
                _formClosed= true;
                Close();
            }
            catch (Exception e)
            {
                MessageBox.Show("Error closing form: " + e.Message);
            }
        }
    }

}
