﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ProxyLayer;

namespace BPMTestApplication
{
    public partial class WorkList : Form
    {
        private Adapter _adapter;
        private string _guid;
        private WorkItem[] _items;

        public WorkList(Adapter adapter,string resourceGuid)
        {
            _adapter = adapter;
            _guid = resourceGuid;

            InitializeComponent();
            ShowWorkList();
        }

        private void ShowWorkList()
        {

            workListTable.Enabled = false;
            workListTable.ForeColor = Color.Gray; 

            try
            {
                WorkItem[] items = _adapter.GetWorkList(_guid);

                _items = items;
                DataSet dsForDGV = new DataSet();
                BindingSource bs = new BindingSource();

                DataTable dataTable1 = ConvertWorkItemsToDataTable(items);
                dsForDGV.Tables.Add(dataTable1);

                bs.DataSource = dsForDGV;
                bs.DataMember = dsForDGV.Tables[0].TableName;

                workListTable.DataSource = bs;

                workListTable.Columns[3].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
            
            }
            catch (Exception ex)
            {
                MessageBox.Show(this,"Error getting work list: "+ex.Message,"Error");
            }

            workListTable.Enabled = true;
            workListTable.ForeColor = Color.Black;

        }

        private DataTable ConvertWorkItemsToDataTable(WorkItem[] items)
        {
            DataTable dataTable1 = new DataTable("MyTable");
            dataTable1.Columns.Add(new DataColumn("Work Item ID"));
            dataTable1.Columns.Add(new DataColumn("State"));
            dataTable1.Columns.Add(new DataColumn("Name"));
            dataTable1.Columns.Add(new DataColumn("Description"));
            dataTable1.Columns.Add(new DataColumn("Process Template"));
            dataTable1.Columns.Add(new DataColumn("Work Item Priority"));
            dataTable1.Columns.Add(new DataColumn("Attribute 2"));


            int i = 0;
            foreach (WorkItem item in items)
            {
                dataTable1.Rows.Add(item.id);
                dataTable1.Rows[i][0] = item.id.id;
                dataTable1.Rows[i][1] = item.state;
                dataTable1.Rows[i][2] = item.header.name;
                dataTable1.Rows[i][3] = item.header.description;
                dataTable1.Rows[i][4] = item.header.itemContext.appName;
                dataTable1.Rows[i][5] = item.header.priority;
                if ((item.attributes != null) && (item.attributes.attribute2 != null))
                {
                    dataTable1.Rows[i][6] = item.attributes.attribute2;
                }
                else
                {
                    dataTable1.Rows[i][6] = "";
                }
                i++;
            }


            return dataTable1;

        }

        private void toolStripButton1_Click(object sender, EventArgs e)
        {
            ShowWorkList();
        }

        private void workListDblClick(object sender, DataGridViewCellEventArgs e)
        {
            int row = e.RowIndex;

            WorkItem item = _items[row];

            try
            {
                ViewWorkItem viewItem = new ViewWorkItem(_adapter,_guid, item);

                ShowWorkList();
                viewItem.ShowDialog();

                ShowWorkList();
            }
            catch (Exception ex)
            {
                ; // Do nothing here as the ViewWorkItem will notify the user of issues
            }


        }


    }
    
}
